<p align="center">
  <img src=https://vignette.wikia.nocookie.net/warhammer40k/images/3/3f/IoMhighres.png/revision/latest/scale-to-width-down/620?cb=20190630130844 />
</p>

<h1 align="center"> imperial-dateutil </h1>

<img align="right" src=https://giantbomb1.cbsistatic.com/uploads/original/1/17172/1415053-imperium_036.jpg height=300>

A utility to use Imperial Dating System(include Era Indomitus Dating System)

> The Emperor protects always and forever. He is the Omnissiah and will always live, always protect, always watch. He will protect all loyal to the Imperium and it is an honor to fight and die in the name of the emperor.

```
pip install imperial-dateutil
```

## Documentation
[Here is the documentation](https://imperial-dateutil.readthedocs.io/en/latest/)

## Features
- Original Imperial Dating System
- Era Indomitus Dating System

## Prerequesties
- Belief to The Emperor, the Omnisiah's avatar
- A little ability of Lingua-technis and row gothic

---

> GW, Games Workshop, Citadel, Black Library, Forge World, Warhammer, the Twin-tailed Comet logo, Warhammer 40,000, the ‘Aquila’ Double-headed Eagle logo, Space Marine, 40K, 40,000, Warhammer Age of Sigmar, Battletome, Stormcast Eternals, White Dwarf, Blood Bowl, Necromunda, Space Hulk, Battlefleet Gothic, Dreadfleet, Mordheim, Inquisitor, Warmaster, Epic, Gorkamorka, and all associated logos, illustrations, images, names, creatures, races, vehicles, locations, weapons, characters, and the distinctive likenesses thereof, are either ® or TM, and/or © Games Workshop Limited, variably registered around the world. All Rights Reserved.